@@ -27,13 +27,14 @@ class Issue(BaseModel):
     project_items: list = Field(default_factory=list)
     assignees: list = Field(default_factory=list)
     labels: List[Label] = Field(default_factory=list)
-    parent: Optional['Issue'] = None
-    sub_issues: List['Issue'] = Field(default_factory=list)
+    parent: Optional["Issue"] = None
+    sub_issues: List["Issue"] = Field(default_factory=list)
 
     # Custom fields
     sprint: Optional[str] = None
     estimate: Optional[int] = None
     status: Optional[str] = None
+    is_archived: bool = Field(default=False, alias="isArchived")
 
 
 class ProjectV2Item(BaseModel):
@@ -43,6 +44,7 @@ class ProjectV2Item(BaseModel):
     content: Optional[Issue] = None
     status: Optional[str] = None
     estimate: Optional[int] = None
+    is_archived: bool = Field(default=False, alias="isArchived")
 
 
 class Project(BaseModel):
@@ -51,4 +53,4 @@ class Project(BaseModel):
     id: str
     title: str
     number: int
-    url: str
+    url: str
\ No newline at end of file
